@@ -11,7 +11,6 @@ import pandas as pd
 from loguru import logger
 import mns_common.api.ths.concept.web.ths_company_info_web as ths_company_info_web
 import mns_common.api.em.east_money_stock_v2_api as east_money_stock_v2_api
-import mns_scheduler.company_info.constant.company_constant_data as company_constant_data
 import mns_common.component.common_service_fun_api as common_service_fun_api
 import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api
 from mns_common.db.MongodbUtil import MongodbUtil
@@ -22,6 +21,7 @@ import mns_common.component.company.company_common_service_api as company_common
 import mns_common.component.k_line.common.k_line_common_service_api as k_line_common_service_api
 import mns_common.constant.db_name_constant as db_name_constant
 from functools import lru_cache
+import mns_scheduler.company_info.base.sync_company_hold_info_api as sync_company_hold_info_api
 
 mongodb_util = MongodbUtil('27017')
 # 分页大小
@@ -35,7 +35,7 @@ result = []
 
 
 # 计算实际流通比例
-def calculate_circu_ratio(symbol):
+def calculate_circulation_ratio(symbol):
     query = {"symbol": symbol}
     stock_gdfx_free_top_10 = mongodb_util.descend_query(query, 'stock_gdfx_free_top_10', "period", 10)
     if stock_gdfx_free_top_10.shape[0] == 0:
@@ -151,6 +151,9 @@ def single_thread_sync_company_info(east_money_stock_info,
     fail_list = []
     for company_one in east_money_stock_info.itertuples():
         try:
+            # 同步公司控股子公司信息 异步执行
+            sync_company_hold_info_api.sync_company_hold_info(company_one.symbol)
+
             company_info_type = ths_company_info_web.get_company_info_detail(company_one.symbol)
             company_info_type = set_kzz_debt(company_info_type, company_one.symbol)
             company_info_type['first_industry_code'] = company_info_type['hycode'].apply(
@@ -159,7 +162,11 @@ def single_thread_sync_company_info(east_money_stock_info,
                 lambda x: x[1:5] + '00')
             company_info_type['third_industry_code'] = company_info_type['hy3code'].apply(
                 lambda x: x[1:7])
-
+            # company_info_type['main_business_list'] = company_info_type['main_business_list']
+            # company_info_type['most_profitable_business'] = company_info_type['most_profitable_business']
+            # company_info_type['most_profitable_business_rate'] = company_info_type['most_profitable_business_rate']
+            # company_info_type['most_profitable_business_profit'] = company_info_type['most_profitable_business_profit']
+            #
             company_info_type['first_sw_industry'] = company_info_type['hy']
             company_info_type['second_sw_industry'] = company_info_type['hy2']
             company_info_type['third_sw_industry'] = company_info_type['hy3']
@@ -194,7 +201,7 @@ def single_thread_sync_company_info(east_money_stock_info,
             company_info_type['total_mv_sp'] = company_one.total_mv_sp
             company_info_type['flow_mv_level'] = company_one.flow_mv_level
             company_info_type['classification'] = company_one.classification
-            company_info_type['mv_circulation_ratio'] = calculate_circu_ratio(company_one.symbol)
+            company_info_type['mv_circulation_ratio'] = calculate_circulation_ratio(company_one.symbol)
             # 获取同花顺最新概念
             company_info_type = ths_concept_common_service_api.set_ths_concept(company_one.symbol, company_info_type)
             now_date = datetime.now()
@@ -417,6 +424,8 @@ def get_recent_year_income(symbol, company_info_type, exist_company_df):
     return company_info_type
 
 
+import mns_scheduler.company_info.constant.company_constant_data as company_constant_data
+
 if __name__ == '__main__':
     # sync_company_base_info()
     # fix_company_industry()
@@ -425,8 +434,8 @@ if __name__ == '__main__':
     # 300293
     # sync_company_base_info(None)
     # new_company_info_update()
-    query = {"total_operate_income": 0}
-    un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
-    symbol_list = list(un_report_company_info['symbol'])
-    sync_company_base_info(symbol_list)
+    # query = {"total_operate_income": 0}
+    # un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
+    # symbol_list = list(un_report_company_info['symbol'])
+    sync_company_base_info(None)
     # group_by_industry()
