@@ -13,7 +13,7 @@ mongodb_util = MongodbUtil('27017')
 
 
 def clean_history_data():
-    query = {"$and": [{"trade_date": {"$gte": '2023-11-06'}}, {"trade_date": {"$lte": '2024-05-29'}}]}
+    query = {"$and": [{"trade_date": {"$gte": '2023-11-06'}}, {"trade_date": {"$lte": '2025-02-05'}}]}
     trade_date_list_df = mongodb_util.find_query_data('trade_date_list', query)
     trade_date_list_df = trade_date_list_df.sort_values(by=['trade_date'], ascending=False)
     for trade_data_one in trade_date_list_df.itertuples():
@@ -25,6 +25,13 @@ def clean_history_data():
 
 
 if __name__ == '__main__':
+    # k_line_info_clean_task.sync_k_line_info('2025-02-21', None)
+    # k_line_info_clean_task.sync_k_line_info('2024-12-19', ['600992'])
+    clean_history_data()
+    k_line_info_clean_task.sync_k_line_info('2025-02-21', ['301458'])
+
     # 001389  001359
-    k_line_info_clean_task.sync_k_line_info('2024-07-12', ['300784'])
+    # k_line_info_clean_task.sync_k_line_info('2025-02-14', None)
+    # k_line_info_clean_task.sync_k_line_info('2025-02-17', None)
+
     # clean_history_data()
