@@ -7,10 +7,8 @@ project_path = file_path[0:end]
 sys.path.append(project_path)
 
 import mns_common.constant.db_name_constant as db_name_constant
-
-from mns_common.db.MongodbUtil import MongodbUtil
-
 import mns_scheduler.risk.financial_report_risk_check_api as financial_report_risk_check_api
+from mns_common.db.MongodbUtil import MongodbUtil
 
 mongodb_util = MongodbUtil('27017')
 
@@ -18,7 +16,7 @@ mongodb_util = MongodbUtil('27017')
 def fix_profit_black_list():
     period_time = "2023-12-31 00:00:00"
     period = 4
-    report_type_list = [db_name_constant.EM_STOCK_PROFIT, db_name_constant.EM_STOCK_ASSET_LIABILITY]
+    report_type_list = [db_name_constant.EM_STOCK_ASSET_LIABILITY, db_name_constant.EM_STOCK_PROFIT]
     for report_type in report_type_list:
         query = {'REPORT_DATE': period_time}
         em_stock_profit_df_list = mongodb_util.find_query_data(report_type, query)
