@@ -16,7 +16,7 @@ import mns_scheduler.zb.stock_zb_pool_sync as stock_zb_pool_sync_api
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
 import mns_common.utils.date_handle_util as date_handle_util
 import mns_scheduler.k_line.sync.daily_week_month_line_sync as daily_week_month_line_sync_api
-import mns_common.utils.ip_util as ip_util
+import mns_scheduler.company_info.announce.company_announce_sync_service as company_announce_sync_service
 import mns_scheduler.db.col_move_service as col_move_service
 import mns_scheduler.db.db_status as db_status_api
 import mns_scheduler.big_deal.ths_big_deal_sync as ths_big_deal_sync_api
@@ -43,18 +43,20 @@ import mns_scheduler.irm.stock_irm_cninfo_service as stock_irm_cninfo_service
 import mns_scheduler.open.sync_one_day_open_data_to_db_service as sync_one_day_open_data_to_db_service
 import mns_scheduler.zt.high_chg.sync_high_chg_pool_service as sync_high_chg_pool_service
 import mns_scheduler.zt.high_chg.sync_high_chg_real_time_quotes_service as sync_high_chg_real_time_quotes_service
-import mns_scheduler.risk.self.wei_pan_stock_api as wei_pan_stock_api
 import mns_scheduler.risk.transactions.transactions_check_api as transactions_check_api
 import mns_scheduler.concept.ths.sync_new_index.sync_ths_concept_new_index_api as sync_ths_concept_new_index_api
 import mns_scheduler.company_info.clean.company_info_clean_api as company_info_clean_api
 import mns_scheduler.zt.zt_pool.ths_zt_pool_sync_api as ths_zt_pool_sync_api
-import mns_scheduler.db.real_time_task_check as real_time_task_check_api
 import mns_scheduler.trade.task.trader_task_service as trader_task_service
 import mns_scheduler.company_info.remark.company_remark_info_sync as company_remark_info_sync
 import mns_scheduler.finance.sync_financial_report_service_api as sync_financial_report_service_api
 import mns_scheduler.hk.hk_industry_info_sync_service_api as hk_industry_info_sync_service_api
 import mns_scheduler.hk.hk_company_info_sync_service_api as hk_company_info_sync_service_api
 import mns_scheduler.zt.zt_pool.update_null_zt_reason_api as update_null_zt_reason_api
+import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
+import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
+import mns_scheduler.db.task_handle_service as task_handle_service
+import mns_scheduler.extraIncome.one_minute.one_minute_sync_task as one_minute_sync_task
 
 
 # 同步交易日期任务完成
@@ -79,6 +81,8 @@ def sync_stock_zb_pool():
     if trade_date_common_service_api.is_trade_day(str_now_day):
         stock_zb_pool_sync_api.sync_stock_zb_pool(str_now_day)
         logger.info("同步炸板信息任务执行成功:{}", str_now_day)
+    # 同步停复牌信息
+    sync_stock_tfp()
 
 
 # 定时同步每周交易行情数据(前复权)
@@ -106,12 +110,7 @@ def col_data_move():
     str_day = now_date.strftime('%Y-%m-%d')
     logger.info('当天实时数据备份:{}', str_day)
     if trade_date_common_service_api.is_trade_day(str_day):
-        mac_address = ip_util.get_mac_address()
-        if mac_address is not None and mac_address == ip_util.WINDOWS_MAC_ADDRESS_CD:
-            col_move_service.sync_col_move(str_day)
-        else:
-            # 删除最早一天数据
-            col_move_service.delete_exist_data(str_day)
+        col_move_service.sync_col_move(str_day)
 
 
 # db 状态check
@@ -292,7 +291,7 @@ def sync_new_concept_index_task():
 # 清洗公司基本信息
 def update_company_base_info():
     company_info_sync_api.sync_company_base_info(None)
-    company_info_clean_api.fix_company_industry(None)
+    company_info_clean_api.clean_company_info(None)
     # 退市股票同步
     de_list_stock_service.sync_de_list_stock()
     logger.info('同步公司基本信息任务完成')
@@ -331,9 +330,9 @@ def sync_kpl_best_his_quotes():
 def sync_high_risk_stocks():
     logger.info('同步被立案调查的股票')
     register_and_investigate_stock_sync_api.sync_register_and_investigate_stocks()
-    reason_detail = '微盘股拉黑'
-    concept_code_wei_pan = '883418'
-    wei_pan_stock_api.add_concept_to_lack_list(concept_code_wei_pan, reason_detail)
+    # reason_detail = '微盘股拉黑'
+    # concept_code_wei_pan = '883418'
+    # wei_pan_stock_api.add_concept_to_lack_list(concept_code_wei_pan, reason_detail)
     logger.info('同步交易类风险的股票')
     transactions_check_api.transactions_check_task()
 
@@ -349,9 +348,16 @@ def sync_all_interactive_questions():
         stock_irm_cninfo_service.sync_all_interactive_questions(None)
 
 
-# 数据同步状态check
-def real_time_task_check_status():
-    real_time_task_check_api.run_check_real_time_data_sync_status()
+# 重开定时任务同步
+def real_time_sync_task_open():
+    logger.info("开启实时行情同步任务")
+    task_handle_service.real_time_sync_task_open()
+
+
+# 关闭实时行情任务
+def real_time_sync_task_close():
+    logger.info("关闭实时行情同步任务")
+    task_handle_service.real_time_sync_task_close()
 
 
 # 打开交易客户端
@@ -394,6 +400,30 @@ def update_null_zt_reason():
         logger.info("更新空涨停原因信息:{}", str_now_day)
 
 
+# 同步公告信息
+def sync_company_announce():
+    company_announce_sync_service.sync_company_announce()
+
+
+# 同步停复牌信息
+def sync_stock_tfp():
+    now_date = datetime.now()
+    str_day = now_date.strftime('%Y-%m-%d')
+    stock_tfp_info_sync.sync_stock_tfp(str_day)
+
+
+def sync_ths_industry_info():
+    logger.info("同步同花顺行业信息开始")
+    ths_industry_sync_service.sync_ths_industry_index()
+    ths_industry_sync_service.sync_ths_industry_detail()
+    logger.info("同步同花顺行业信息完成")
+
+
+def sync_one_minute_data():
+    logger.info("同步1分钟交易数据")
+    one_minute_sync_task.sync_one_minute_data()
+
+
 # # 定义BlockingScheduler
 blockingScheduler = BlockingScheduler()
 # sync_trade_date 同步交易日期
@@ -412,11 +442,14 @@ blockingScheduler.add_job(stock_sync_qfq_weekly, 'cron', day_of_week='fri', hour
 blockingScheduler.add_job(stock_sync_qfq_monthly, 'cron', hour='15,18', minute='35')
 
 # 数据备份
-blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='33')
+blockingScheduler.add_job(col_data_move, 'cron', hour='15', minute='26')
 
 # 数据库健康检查
 blockingScheduler.add_job(db_status_check, 'interval', seconds=30, max_instances=4)
 
+# 同步停复牌信息
+
+
 # 同步大单数据 暂停同步 20240430
 # blockingScheduler.add_job(sync_ths_big_deal, 'cron', hour='09', minute='30', max_instances=4)
 
@@ -426,7 +459,7 @@ blockingScheduler.add_job(db_status_check, 'interval', seconds=30, max_instances
 blockingScheduler.add_job(sync_daily_data_info, 'cron', hour='15,20', minute='26')
 
 # 开盘前同步当天交易需要的k线数据
-blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='08', minute='30')
+blockingScheduler.add_job(sync_today_trade_k_line_info, 'cron', hour='07', minute='40')
 
 # 同步十大流通股东信息
 blockingScheduler.add_job(sync_stock_gdfx_free_top_10_one_day, 'cron', hour='08,22', minute='23')
@@ -438,7 +471,7 @@ blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24
 blockingScheduler.add_job(update_concept_all_detail_info, 'cron', hour='08,18,12', minute='30')
 
 # 同步单只股票下所有概念 by 股票代码
-blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='08,09,18', minute='15')
+blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='08,09,18', minute='00')
 # 同步单只股票下所有概念 by 股票代码 中午任务执行
 blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='12', minute='15,40')
 
@@ -473,16 +506,54 @@ blockingScheduler.add_job(sync_high_risk_stocks, 'cron', hour='0,09,12,16', minu
 
 # 同步互动回答
 blockingScheduler.add_job(sync_all_interactive_questions, 'cron', hour='08,12,17', minute='05')
+#
+# # 添加第一个时间段的任务：9:25 到 11:30，每 10 秒执行一次
+# blockingScheduler.add_job(
+#     real_time_task_check_status,
+#     'cron',
+#     hour='9-11',  # 9 点到 11 点
+#     minute='25-59',  # 25 分到 59 分（9:25-9:59）
+#     second='*/30',  # 每 20 秒
+#     max_instances=4
+# )
+#
+# # 添加第二个时间段的任务：10:00 到 11:30，每 10 秒执行一次
+# blockingScheduler.add_job(
+#     real_time_task_check_status,
+#     'cron',
+#     hour='10-11',  # 10 点到 11 点
+#     minute='*',  # 每分钟
+#     second='*/30',  # 每 20 秒
+#     max_instances=4
+# )
+#
+# # 添加第三个时间段的任务：13:00 到 15:00，每 10 秒执行一次
+# blockingScheduler.add_job(
+#     real_time_task_check_status,
+#     'cron',
+#     hour='13-15',  # 13 点到 15 点
+#     minute='*',  # 每分钟
+#     second='*/30',  # 每 20 秒
+#     max_instances=4
+# )
 
-# 实时数据状态同步check
-blockingScheduler.add_job(real_time_task_check_status, 'interval', seconds=59, max_instances=4)
+# 重开定时任务同步
+
+blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='25')
+blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='29')
+blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='12', minute='59')
+# 关闭实时行情任务
+
+blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='09', minute='27')
+blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='11', minute='31')
+blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='15', minute='01')
 
 # 打开交易客户端
 blockingScheduler.add_job(trader_client_auto_login, 'cron', hour='08,12', minute='30')
 # 同步公司备注信息
 blockingScheduler.add_job(sync_company_remark_info, 'cron', hour='22', minute='30')
 # 自选股操作
-blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='17,22', minute='30')
+blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='08,17,21', minute='30')
 # 同步财务报表任务
 blockingScheduler.add_job(sync_financial_report_task, 'cron', hour='17', minute='30')
 
@@ -491,8 +562,18 @@ blockingScheduler.add_job(sync_hk_company_industry_info, 'cron', hour='08,15', m
 # 更新空的涨停原因股票
 blockingScheduler.add_job(update_null_zt_reason, 'cron', hour='16,17,18,19,20,21,22,23', minute='19')
 
+# 同步同花顺行业信息
+blockingScheduler.add_job(sync_ths_industry_info, 'cron', hour='17,22', minute='38')
+
+# 同步一分钟交易数据
+blockingScheduler.add_job(sync_one_minute_data, 'cron', hour='17,22', minute='55')
+
+# 同步新公告信息 感觉没有必要同步 直接连接过去查看
+# blockingScheduler.add_job(sync_company_announce, 'cron', hour='07,18,23', minute='33')
+
 print('定时任务启动成功')
 blockingScheduler.start()
 #
 # if __name__ == '__main__':
+#
 #     sync_daily_data_info()
